===============
Release History
===============

Initial Release (2019-11-09)
----------------------------
Initial release. Three modules added.

v0.2.0 Release (2019-11-09)
---------------------------
Added features based on filters. Changed function 'extractFeatures' to allow the user select the features.
